@@ -12,8 +12,14 @@ server:
   url: http://default
   user: ${oc.env:USER}
   home: "~"
+show: false
+exception: false
 """,
-    {"server": "Contains the arguments for the demo"},
+    {
+        "server": "Arguments for the demo",
+        "show": "The name of the selection to show",
+        "exception": "If set, raise an exception",
+    },
 )
 
 
@@ -23,10 +29,14 @@ def main():
     # ./example-simple.py logging.handlers.console.formatter=json
     logging.info('The app is running...', extra={'other': 'othervalue'})
     # get the application name from the configuration
-    print('app:', alphaconf.configuration().application.name)
+    print('app:', alphaconf.configuration.get().application.name)
     # shortcut version to get a configuration value
     print('server.user:', alphaconf.get('server.user'))
     print('server.home', alphaconf.get('server.home', Path))
+    # show configuration
+    value = alphaconf.get('show')
+    if value and (value := alphaconf.get(value)):
+        print(value)
     # log an exception if we have it in the configuration
     if alphaconf.get('exception'):
         try:
@@ -36,8 +46,9 @@ def main():
 
 
 if __name__ == '__main__':
-    alphaconf.Application(
+    alphaconf.run(
+        main,
         name='example',
         version='0.1',
         description="Simple demo of alphaconf",
-    ).run(main)
+    )
